/*
 * genfake
 *
 * This program generates the fake run file used by genscore from
 * "java pc2.Report -all"
 *
 * This is useful for a multi-site contest, so that one site can dump its
 * runs into a fake run file to be read by genscore at another site.
 *
 * genfake
 *
 * Note: we also allow simulated runs from a file "fake_runs", in the following
 * format:
 *
 * ----------------BEGIN FILE--------------------------
 * Name of fake team 1
 *    ...
 * Name of fake team n
 * #
 * team name|problem|minutes|accept|deleted
 *    ...
 * team name|problem|minutes|accept|deleted
 * #
 * -----------------END FILE---------------------------
 *
 * where problem is 1, 2, 3, ...
 *       accept is Y or N
 *       deleted is Y or N
 *
 * Author: Howard Cheng
 *
 */

#include <stdio.h>
#include <string.h>
#include <stdlib.h>
#include <time.h>
#include <ctype.h>

#define FAKE_FILE   "fake_runs"

FILE *fake;

static void get_runs(void);

int main(void)
{
  /* open fake file, if any */
  if (!(fake = fopen(FAKE_FILE, "w"))) {
    fprintf(stderr, "Cannot open \"%s\" for writing.\n", FAKE_FILE);
    return -1;
  }

  /* parse the runs */
  get_runs();

  fclose(fake);

  return 0;
}

static void get_runs(void)
{
  char buffer[10240], buffer2[10240], *p, *s;
  int prob, stime, deleted, accept;

  fprintf(fake, "#\n");
  while (fgets(buffer, 10240, stdin) && strcmp(buffer, "-- Runs --\n"))
    ;

  while (1) {
    if (!fgets(buffer, 10240, stdin) ||
	strstr(buffer, "No runs to list/print")) {
      break;
    }
    
    /* first get the team name */
    if (!(p = strtok(buffer, "|\n"))) {
      break;
    }
    p = strtok(0, "|\n");
    p = strtok(0, "|\n");
    p = strtok(0, "|\n");
    s = strchr(p, ':');
    fprintf(fake, "%s|", s+1);
    
    /* now get problem */
    p = strtok(0, "|\n");
    sscanf(p, "prob %d", &prob);
    fprintf(fake, "%d|", prob);
    
    /* now get the time */
    p = strtok(0, "|\n");
    p = strtok(0, "|\n");
    p = strtok(0, "|\n");
    p = strtok(0, "|\n");
    p = strtok(0, "|\n");
    p = strtok(0, "|\n");
    stime = atoi(p);
    fprintf(fake, "%d|", stime);
    
    /* now see if it's deleted */
    p = strtok(0, "|\n");
    p = strtok(0, "|\n");
    sscanf(p, "del? %s", buffer2);
    deleted = (!strcmp(buffer2, "true")) ? 1 : 0;
    
    /* now get the judgement */
    p = strtok(0, "|\n");
    if (strcmp(p, "<null>")) {
      sscanf(p, "jci %d", &accept);
      accept = !accept;
    } else {
      accept = 0;
    }
    fprintf(fake, "%c|%c\n", (accept) ? 'Y' : 'N', (deleted) ? 'Y' : 'N');
  }

  fprintf(fake, "#\n");
}
