#!/bin/sh
#
# vi ts=4:sw=4:ai:ic
#
#  File:        v7judge.sh
#  Purpose:     used as juding script (compile and execute) for pc2 v7
#  System:      CSUS Programming Contest system (pc2)
#  Environment: Unix
#  Author:      pc2@ecs.csus.edu (laned)
#  Revised: Wed Oct  6 22:32:43 PDT 1999
#
#  Revision 4 - laned 
#   In order to show what is generated by this script all output lines
#      from this script are preceeded by -- in the output file.
#   Added check for input file
#   Added check for whether executable is generated, if that applies.
#   Better messages when fails during compile
# 

# 
#  Parameters:
#  1:  name of file with extension (no path) ie.  proba.java
#  2:  name of file with no extension
#  3:  language/compiler name
#

#
#  Examples:
#  sh v7judge.sh hello.java hello java
#  sh v7judge.sh hello.c hello cpp
#

#
# Name of output file 
#
OUTFILE=output
rm -f $OUTFILE

#
# Viewer Command
#
VIEWER="cat "
VIEWER="xterm -e view "

echo "-- Date/time for run: " `date` >> $OUTFILE

if [ "$DISPLAY" = "" ] ; then
    echo "Note: DISPLAY environmental variable not set, bummer "
fi

#
# Under pc2 this should never occur, but if hand executed it may
#
if [ "$1" != "" ] ; then
	if [ ! -f "$1" ] ; then
		echo
	    echo "-- source file $1 does not exist   --" >> $OUTFILE
	    echo "Script halted, missing source file --" >> $OUTFILE
		echo 
		$VIEWER $OUTFILE
		exit 2
	fi
fi 

#
# Usage 
#
if [ "$1" = "" ] ; then

    echo "$0 filename basename langname "
    echo 
    echo Compiles filename and runs basename, output to a file named $OUTFILE 
    echo then displays that file using the following command: $VIEWER
    echo 
    echo Parameters:
    echo " filename - name of file with extension (no path) ie.  proba.java"
    echo " basename - name of file with no extension ie. proba"
    echo " langname - language/compiler name (Ex. cc) "
    echo
    echo Example of usage: sh v7judge.sh hello.java hello java
    echo
    echo "This script is part of pc2.  http://ecs.csus.edu/pc2 or e-mail pc2@ecs.csus.edu"
    echo for questions
    echo

elif [ "$3" = "perl" ] ; then

    echo "-- Output for $1 --" >> $OUTFILE
    echo Executing program $1
    /usr/bin/perl $1 2>&1 >> $OUTFILE
    echo "-- End Output Listing $2 --" >> $OUTFILE
    echo program done - starting viewer...

    $VIEWER $OUTFILE

elif [ "$3" = "gcc" ] ; then

	# There may be many commands for C++
    CC=gcc
    CC=g++
	CCPATH=/usr/bin

	# remove target executable
	rm -f $2

    echo "Compiling $1 using $CC "
    echo "-- Compiler listing for $1 using $3  --" >> $OUTFILE

    $CCPATH/$CC -o $2 $1 2>&1 >> $OUTFILE

	if [ -f ./$2 ] ; then 
		echo "-- Output for $2 --" >> $OUTFILE
		echo Executing program $2
		./$2 >> $OUTFILE
	else
		echo "Compile failed - program $2 not created " >> $OUTFILE
	fi

    echo "-- End Output Listing $2 --" >> $OUTFILE
    echo program done - starting viewer...

    $VIEWER $OUTFILE

elif [ "$3" = "cc" ] ; then

    CC=cc
	CCPATH=/usr/bin

	# remove target executable
	rm -f $2

    echo "Compiling $1 using $CC "
    echo "-- Compiler listing for $1 using $3  --" >> $OUTFILE

    $CCPATH/$CC -o $2 $1 2>&1 >> $OUTFILE

	if [ -f ./$2 ] ; then 
		echo "-- Output for $2 --" >> $OUTFILE
		echo Executing program $2
		./$2 >> $OUTFILE
	else
		echo "Compile failed - program $2 not created " >> $OUTFILE
	fi

    echo "-- End Output Listing $2 --" >> $OUTFILE
    echo program done - starting viewer...

    $VIEWER $OUTFILE

elif [ "$3" = "java" ] ; then

    echo Compiling Java

    JAVAHOME=/usr/jdk1.1.7 
    JAVAHOME=/usr/jdk_base/

    export PATH=PATH:$JAVAHOME/bin:$PATH
    export CLASSPATH=.:$JAVAHOME/lib:$CLASSPATH

	# remove target executable
	rm -f $2.class

    echo "Compiling $1 using java"
    echo "-- Compiler listing for $1 using $3  --" >> $OUTFILE

    javac $1 2>&1 >> $OUTFILE 

	if [ -f ./$2.class ] ; then 
		echo "-- Output for $2 --" >> $OUTFILE
		echo Executing program $2
		java $2  >> $OUTFILE
	else
		echo "Compile failed - program $2.class not created " >> $OUTFILE
	fi

    echo "-- End Output Listing $2 --" >> $OUTFILE

    echo program done - starting viewer...

    $VIEWER $OUTFILE

else

    echo "Error - Unknown language $3, contact Contest Staff "  
    echo "Error - Unknown language $3, contact Contest Staff "  > $OUTFILE

    $VIEWER $OUTFILE
fi

#  end of script
